@@ -1,3 +1,4 @@
+use lettre::message::SinglePart;
 use lightspeed_email::config::EmailClientConfig;
 use lightspeed_email::model::email::{EmailAttachment, EmailMessage};
 use lightspeed_email::repository::email::{new, EmailClientType};
@@ -53,18 +54,45 @@ async fn should_start_the_mailserver() {
     assert!(email_service.send(message.clone()).await.is_ok());
 }
 
-/*
+#[ignore]
+#[tokio::test]
+async fn full_client_should_use_gmail2() {
+    use lettre::transport::smtp::authentication::Credentials;
+    use lettre::{Message, SmtpTransport, Transport};
+
+    let email = Message::builder()
+        .from("NoBody <ufoscout@gmail.com>".parse().unwrap())
+        .reply_to("Yuin <ufoscout@gmail.com>".parse().unwrap())
+        .to("Hei <ufoscout@gmail.com>".parse().unwrap())
+        .subject("Happy new year")
+        .singlepart(SinglePart::plain("hello".to_owned()))
+        .unwrap();
+
+    let creds = Credentials::new("ufoscout@gmail.com".to_string(), "".to_string());
+
+    // Open a remote connection to gmail
+    let mailer = SmtpTransport::starttls_relay("smtp.gmail.com").unwrap().credentials(creds).build();
+
+    // Send the email
+    match mailer.send(&email) {
+        Ok(_) => println!("Email sent successfully!"),
+        Err(e) => panic!("Could not send email: {:?}", e),
+    }
+}
+
+#[ignore]
 #[tokio::test]
 async fn full_client_should_use_gmail() {
     // Arrange
     let config = EmailClientConfig {
-        server_port: 465,
-        server_address: "smtp.gmail.com".to_owned(),
-        client_type: EmailClientType::Full,
-        server_username: "ufoscout@gmail.com".to_owned(),
-        server_password: "".to_owned(),
-        server_use_tls: Boolean::True,
+        email_client_type: EmailClientType::Full,
+        email_client_timeout_seconds: 60,
+        email_server_port: 587,
+        email_server_address: "smtp.gmail.com".to_string(),
+        email_server_username: "ufoscout@gmail.com".to_string(),
+        email_server_password: "".to_string(),
         forward_all_emails_to_fixed_recipients: None,
+        email_server_use_tls: true,
     };
 
     let email_service = new(config).unwrap();
@@ -74,14 +102,7 @@ async fn full_client_should_use_gmail() {
     message.to.push("FRANCESCO <ufoscout@gmail.com>".to_owned());
     message.subject = Some("EMAIL FROM RUST!!".to_owned());
     message.html = Some("HTML body".to_owned());
-    message.attachments.push(EmailAttachment::FromFile {
-        mime_type: "plain/text".to_owned(),
-        path: "./Cargo.toml".to_owned(),
-        filename: Some("cargo.txt".to_owned())
-    });
 
     // Act
     email_service.send(message.clone()).await.unwrap();
-
 }
-*/
